@@ -1,5 +1,4 @@
-/* pkgInterface.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -17,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -40,7 +39,7 @@
 extern Opts *opts;
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-param::param(QString nameP, bool initP,  bool invertP, QString flagP)
+param::param(const QString &nameP, bool initP,  bool invertP, const QString &flagP)
 {
   name = nameP;
   init = initP;
@@ -49,7 +48,7 @@ param::param(QString nameP, bool initP,  bool invertP, QString flagP)
   flagA = "";
 }
 
-param::param(QString nameP, bool initP,  bool invertP,  QString flagP,  QString flagAP )
+param::param(const QString &nameP, bool initP,  bool invertP,  const QString &flagP,  const QString &flagAP )
 {
   name = nameP;
   init = initP;
@@ -79,6 +78,7 @@ pkgInterface::pkgInterface( ) : QObject(), new_pict(), updated_pict()
   hasRemote = FALSE;
   defaultHandle = 1;
   noFetch = FALSE;
+  hasSearchAll = FALSE;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -102,11 +102,22 @@ void pkgInterface::setMenu(KActionCollection*, bool )
 //////////////////////////////////////////////////////////////////////////////
 QStringList pkgInterface::depends(const QString &, int ) {return 0;}
 
-QString pkgInterface::doUninstall(int, QString, bool &) {return 0;}
-QString pkgInterface::doInstall(int, QString, bool &) {return 0;}
+QString pkgInterface::doUninstall(int, const QString &, bool &) {return 0;}
+QString pkgInterface::doInstall(int, const QString &, bool &) {return 0;}
 
 ////////////////////////////////////////////////////////////////////////////
 
+bool pkgInterface::ifExe(QString exe) {
+  if (!KGlobal::dirs()->findExe( exe ).isNull()) {
+    return TRUE;
+  } else {
+    kdDebug() << "Program not found: " << exe << "\n";
+    errExe = exe;
+    return FALSE;
+  }
+}
+
+
 void pkgInterface::listPackages(QPtrList<packageInfo> *pki)
 {
   listInstalledPackages(pki);
@@ -122,7 +133,7 @@ void pkgInterface::listPackages(QPtrList<packageInfo> *pki)
 void pkgInterface::smerge(packageInfo *)
 { }
 
-void pkgInterface::listDir(QPtrList<packageInfo> *pki, QString fname, QString dir, bool subdirs)
+void pkgInterface::listDir(QPtrList<packageInfo> *pki, const QString &fname, const QString &dir, bool subdirs)
 {
   //  fname - path to directory or cached remote infromation file
   //  dir - url of directory
@@ -170,8 +181,8 @@ void pkgInterface::listDir(QPtrList<packageInfo> *pki, QString fname, QString di
 	    rfile += fi->fileName();
 	    p = getPackageInfo('u',rfile, 0);
 	    if (p) {
-	      p->info->insert("filename", new QString(fi->fileName()));
-	      p->info->insert("base", new QString(dir));
+	      p->info.insert("filename", fi->fileName());
+	      p->info.insert("base", dir);
 	    }
 	  } else {
 	    p = collectDir(fi->fileName(),pn.setNum(fi->size()),dir);
@@ -211,21 +222,20 @@ void pkgInterface::listDir(QPtrList<packageInfo> *pki, QString fname, QString di
     }
   }
 
-packageInfo *pkgInterface::collectDir(QString name, QString size, QString dir)
+packageInfo *pkgInterface::collectDir(const QString &name, const QString &size, const QString &dir)
 {
     kdDebug() << "collectDir " << name << " " << size << " " << dir << endl;
     QString n,v;
 
   if (parseName(name, &n, &v)) {
-    QDict<QString> *a = new QDict<QString>;
-    a->setAutoDelete(TRUE);
+    QMap<QString, QString> a;
 
-    a->insert("group", new QString("NEW"));
-    a->insert("name", new QString(n));
-    a->insert("version", new QString(v));
-    a->insert("file-size", new QString(size));
-    a->insert("filename", new QString(name));
-    a->insert("base", new QString(dir));
+    a.insert("group", "NEW");
+    a.insert("name", n);
+    a.insert("version", v);
+    a.insert("file-size", size);
+    a.insert("filename", name);
+    a.insert("base", dir);
 
     packageInfo *i = new packageInfo(a,this);
     i->packageState = packageInfo::AVAILABLE;
@@ -299,7 +309,7 @@ QString pkgInterface::getDir(cacheObj *cp) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-QString  pkgInterface::provMap(QString p)
+QString  pkgInterface::provMap(const QString &p)
 {
   //  kdDebug() << "provMap=>" << p << endl;
   return p;
@@ -387,8 +397,9 @@ QString pkgInterface::install(int installFlags, QPtrList<packageInfo> *p, bool &
 }
 
 //////////////////////////////////////////////////////////////////////////////
-QStringList  pkgInterface::listInstalls(QStringList packs, bool )
+QStringList  pkgInterface::listInstalls(const QStringList &packs, bool , bool &cancel)
 {
+  cancel = FALSE;
   return packs;
 }
 
@@ -417,7 +428,7 @@ QString pkgInterface::setOptions(int flags, QPtrList<param> &params)
   return 0;
 }
 
- void  pkgInterface::writeApt(QStringList)
+ void  pkgInterface::writeApt(const QStringList &)
 {
 }
 
