@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -72,11 +72,11 @@ private:
   packageInfo* collectInfo(const char *inp, int insState);
    void listInstalledPackages(QPtrList<packageInfo> *pki);
 
-  QString doUninstall(int installFlags, QString packs, bool &test);
-  QString doInstall(int installFlags, QString packs, bool &test);
+  QString doUninstall(int installFlags, const QString &packs, bool &test);
+  QString doInstall(int installFlags, const QString &packs, bool &test);
 
   void listPackages(QPtrList<packageInfo> *pki);
-  void listPackList(QPtrList<packageInfo> *pki, QString s,
+  void listPackList(QPtrList<packageInfo> *pki, const QString &s,
 		    cacheObj *cp, int insState);
 
   void initTranslate();
